{% load i18n %}

<div class="modal fade terms in" data-backdrop="static" tabindex="-1" role="dialog" aria-labelledby="Terms" aria-hidden="true">
  <div class="modal-dialog modal-lg" role="document">
    <div class="modal-content">
      <div class="modal-header">
        <h5 class="modal-title">{% trans "Terms & Conditions" %}</h5>
      </div>
      <div class="modal-body">
        {% block terms-body %}
          Write your Terms and Conditions here.
        {% endblock %}
      </div>
      <div class="modal-footer">
        <a href="/" class="btn btn-outline-secondary">{% trans "Disagree" %}</a>
        <button type="button" class="btn btn-primary" data-dismiss="modal">{% trans "Agree" %}</button>
      </div>
    </div>
  </div>
</div>