# Generated by Django 3.0.8 on 2020-07-25 13:20

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import uuid


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Event',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('uuid', models.UUIDField(default=uuid.uuid4, verbose_name='UUID for meeting-URL')),
                ('created_at', models.DateTimeField(default=django.utils.timezone.now, verbose_name='Creation Date')),
                ('start', models.DateTimeField(verbose_name='Date and Time')),
                ('language', models.CharField(choices=[('af', 'Afrikaans'), ('ar', 'Arabic'), ('ast', 'Asturian'), ('az', 'Azerbaijani'), ('bg', 'Bulgarian'), ('be', 'Belarusian'), ('bn', 'Bengali'), ('br', 'Breton'), ('bs', 'Bosnian'), ('ca', 'Catalan'), ('cs', 'Czech'), ('cy', 'Welsh'), ('da', 'Danish'), ('de', 'German'), ('dsb', 'Lower Sorbian'), ('el', 'Greek'), ('en', 'English'), ('en-au', 'Australian English'), ('en-gb', 'British English'), ('eo', 'Esperanto'), ('es', 'Spanish'), ('es-ar', 'Argentinian Spanish'), ('es-co', 'Colombian Spanish'), ('es-mx', 'Mexican Spanish'), ('es-ni', 'Nicaraguan Spanish'), ('es-ve', 'Venezuelan Spanish'), ('et', 'Estonian'), ('eu', 'Basque'), ('fa', 'Persian'), ('fi', 'Finnish'), ('fr', 'French'), ('fy', 'Frisian'), ('ga', 'Irish'), ('gd', 'Scottish Gaelic'), ('gl', 'Galician'), ('he', 'Hebrew'), ('hi', 'Hindi'), ('hr', 'Croatian'), ('hsb', 'Upper Sorbian'), ('hu', 'Hungarian'), ('hy', 'Armenian'), ('ia', 'Interlingua'), ('id', 'Indonesian'), ('io', 'Ido'), ('is', 'Icelandic'), ('it', 'Italian'), ('ja', 'Japanese'), ('ka', 'Georgian'), ('kab', 'Kabyle'), ('kk', 'Kazakh'), ('km', 'Khmer'), ('kn', 'Kannada'), ('ko', 'Korean'), ('lb', 'Luxembourgish'), ('lt', 'Lithuanian'), ('lv', 'Latvian'), ('mk', 'Macedonian'), ('ml', 'Malayalam'), ('mn', 'Mongolian'), ('mr', 'Marathi'), ('my', 'Burmese'), ('nb', 'Norwegian Bokmål'), ('ne', 'Nepali'), ('nl', 'Dutch'), ('nn', 'Norwegian Nynorsk'), ('os', 'Ossetic'), ('pa', 'Punjabi'), ('pl', 'Polish'), ('pt', 'Portuguese'), ('pt-br', 'Brazilian Portuguese'), ('ro', 'Romanian'), ('ru', 'Russian'), ('sk', 'Slovak'), ('sl', 'Slovenian'), ('sq', 'Albanian'), ('sr', 'Serbian'), ('sr-latn', 'Serbian Latin'), ('sv', 'Swedish'), ('sw', 'Swahili'), ('ta', 'Tamil'), ('te', 'Telugu'), ('th', 'Thai'), ('tr', 'Turkish'), ('tt', 'Tatar'), ('udm', 'Udmurt'), ('uk', 'Ukrainian'), ('ur', 'Urdu'), ('uz', 'Uzbek'), ('vi', 'Vietnamese'), ('zh-hans', 'Simplified Chinese'), ('zh-hant', 'Traditional Chinese')], default='en', max_length=10, verbose_name='Language')),
                ('tzname', models.CharField(choices=[('Africa/Abidjan', 'Africa/Abidjan'), ('Africa/Accra', 'Africa/Accra'), ('Africa/Addis_Ababa', 'Africa/Addis_Ababa'), ('Africa/Algiers', 'Africa/Algiers'), ('Africa/Asmara', 'Africa/Asmara'), ('Africa/Bamako', 'Africa/Bamako'), ('Africa/Bangui', 'Africa/Bangui'), ('Africa/Banjul', 'Africa/Banjul'), ('Africa/Bissau', 'Africa/Bissau'), ('Africa/Blantyre', 'Africa/Blantyre'), ('Africa/Brazzaville', 'Africa/Brazzaville'), ('Africa/Bujumbura', 'Africa/Bujumbura'), ('Africa/Cairo', 'Africa/Cairo'), ('Africa/Casablanca', 'Africa/Casablanca'), ('Africa/Ceuta', 'Africa/Ceuta'), ('Africa/Conakry', 'Africa/Conakry'), ('Africa/Dakar', 'Africa/Dakar'), ('Africa/Dar_es_Salaam', 'Africa/Dar_es_Salaam'), ('Africa/Djibouti', 'Africa/Djibouti'), ('Africa/Douala', 'Africa/Douala'), ('Africa/El_Aaiun', 'Africa/El_Aaiun'), ('Africa/Freetown', 'Africa/Freetown'), ('Africa/Gaborone', 'Africa/Gaborone'), ('Africa/Harare', 'Africa/Harare'), ('Africa/Johannesburg', 'Africa/Johannesburg'), ('Africa/Juba', 'Africa/Juba'), ('Africa/Kampala', 'Africa/Kampala'), ('Africa/Khartoum', 'Africa/Khartoum'), ('Africa/Kigali', 'Africa/Kigali'), ('Africa/Kinshasa', 'Africa/Kinshasa'), ('Africa/Lagos', 'Africa/Lagos'), ('Africa/Libreville', 'Africa/Libreville'), ('Africa/Lome', 'Africa/Lome'), ('Africa/Luanda', 'Africa/Luanda'), ('Africa/Lubumbashi', 'Africa/Lubumbashi'), ('Africa/Lusaka', 'Africa/Lusaka'), ('Africa/Malabo', 'Africa/Malabo'), ('Africa/Maputo', 'Africa/Maputo'), ('Africa/Maseru', 'Africa/Maseru'), ('Africa/Mbabane', 'Africa/Mbabane'), ('Africa/Mogadishu', 'Africa/Mogadishu'), ('Africa/Monrovia', 'Africa/Monrovia'), ('Africa/Nairobi', 'Africa/Nairobi'), ('Africa/Ndjamena', 'Africa/Ndjamena'), ('Africa/Niamey', 'Africa/Niamey'), ('Africa/Nouakchott', 'Africa/Nouakchott'), ('Africa/Ouagadougou', 'Africa/Ouagadougou'), ('Africa/Porto-Novo', 'Africa/Porto-Novo'), ('Africa/Sao_Tome', 'Africa/Sao_Tome'), ('Africa/Tripoli', 'Africa/Tripoli'), ('Africa/Tunis', 'Africa/Tunis'), ('Africa/Windhoek', 'Africa/Windhoek'), ('America/Adak', 'America/Adak'), ('America/Anchorage', 'America/Anchorage'), ('America/Anguilla', 'America/Anguilla'), ('America/Antigua', 'America/Antigua'), ('America/Araguaina', 'America/Araguaina'), ('America/Argentina/Buenos_Aires', 'America/Argentina/Buenos_Aires'), ('America/Argentina/Catamarca', 'America/Argentina/Catamarca'), ('America/Argentina/Cordoba', 'America/Argentina/Cordoba'), ('America/Argentina/Jujuy', 'America/Argentina/Jujuy'), ('America/Argentina/La_Rioja', 'America/Argentina/La_Rioja'), ('America/Argentina/Mendoza', 'America/Argentina/Mendoza'), ('America/Argentina/Rio_Gallegos', 'America/Argentina/Rio_Gallegos'), ('America/Argentina/Salta', 'America/Argentina/Salta'), ('America/Argentina/San_Juan', 'America/Argentina/San_Juan'), ('America/Argentina/San_Luis', 'America/Argentina/San_Luis'), ('America/Argentina/Tucuman', 'America/Argentina/Tucuman'), ('America/Argentina/Ushuaia', 'America/Argentina/Ushuaia'), ('America/Aruba', 'America/Aruba'), ('America/Asuncion', 'America/Asuncion'), ('America/Atikokan', 'America/Atikokan'), ('America/Bahia', 'America/Bahia'), ('America/Bahia_Banderas', 'America/Bahia_Banderas'), ('America/Barbados', 'America/Barbados'), ('America/Belem', 'America/Belem'), ('America/Belize', 'America/Belize'), ('America/Blanc-Sablon', 'America/Blanc-Sablon'), ('America/Boa_Vista', 'America/Boa_Vista'), ('America/Bogota', 'America/Bogota'), ('America/Boise', 'America/Boise'), ('America/Cambridge_Bay', 'America/Cambridge_Bay'), ('America/Campo_Grande', 'America/Campo_Grande'), ('America/Cancun', 'America/Cancun'), ('America/Caracas', 'America/Caracas'), ('America/Cayenne', 'America/Cayenne'), ('America/Cayman', 'America/Cayman'), ('America/Chicago', 'America/Chicago'), ('America/Chihuahua', 'America/Chihuahua'), ('America/Costa_Rica', 'America/Costa_Rica'), ('America/Creston', 'America/Creston'), ('America/Cuiaba', 'America/Cuiaba'), ('America/Curacao', 'America/Curacao'), ('America/Danmarkshavn', 'America/Danmarkshavn'), ('America/Dawson', 'America/Dawson'), ('America/Dawson_Creek', 'America/Dawson_Creek'), ('America/Denver', 'America/Denver'), ('America/Detroit', 'America/Detroit'), ('America/Dominica', 'America/Dominica'), ('America/Edmonton', 'America/Edmonton'), ('America/Eirunepe', 'America/Eirunepe'), ('America/El_Salvador', 'America/El_Salvador'), ('America/Fort_Nelson', 'America/Fort_Nelson'), ('America/Fortaleza', 'America/Fortaleza'), ('America/Glace_Bay', 'America/Glace_Bay'), ('America/Goose_Bay', 'America/Goose_Bay'), ('America/Grand_Turk', 'America/Grand_Turk'), ('America/Grenada', 'America/Grenada'), ('America/Guadeloupe', 'America/Guadeloupe'), ('America/Guatemala', 'America/Guatemala'), ('America/Guayaquil', 'America/Guayaquil'), ('America/Guyana', 'America/Guyana'), ('America/Halifax', 'America/Halifax'), ('America/Havana', 'America/Havana'), ('America/Hermosillo', 'America/Hermosillo'), ('America/Indiana/Indianapolis', 'America/Indiana/Indianapolis'), ('America/Indiana/Knox', 'America/Indiana/Knox'), ('America/Indiana/Marengo', 'America/Indiana/Marengo'), ('America/Indiana/Petersburg', 'America/Indiana/Petersburg'), ('America/Indiana/Tell_City', 'America/Indiana/Tell_City'), ('America/Indiana/Vevay', 'America/Indiana/Vevay'), ('America/Indiana/Vincennes', 'America/Indiana/Vincennes'), ('America/Indiana/Winamac', 'America/Indiana/Winamac'), ('America/Inuvik', 'America/Inuvik'), ('America/Iqaluit', 'America/Iqaluit'), ('America/Jamaica', 'America/Jamaica'), ('America/Juneau', 'America/Juneau'), ('America/Kentucky/Louisville', 'America/Kentucky/Louisville'), ('America/Kentucky/Monticello', 'America/Kentucky/Monticello'), ('America/Kralendijk', 'America/Kralendijk'), ('America/La_Paz', 'America/La_Paz'), ('America/Lima', 'America/Lima'), ('America/Los_Angeles', 'America/Los_Angeles'), ('America/Lower_Princes', 'America/Lower_Princes'), ('America/Maceio', 'America/Maceio'), ('America/Managua', 'America/Managua'), ('America/Manaus', 'America/Manaus'), ('America/Marigot', 'America/Marigot'), ('America/Martinique', 'America/Martinique'), ('America/Matamoros', 'America/Matamoros'), ('America/Mazatlan', 'America/Mazatlan'), ('America/Menominee', 'America/Menominee'), ('America/Merida', 'America/Merida'), ('America/Metlakatla', 'America/Metlakatla'), ('America/Mexico_City', 'America/Mexico_City'), ('America/Miquelon', 'America/Miquelon'), ('America/Moncton', 'America/Moncton'), ('America/Monterrey', 'America/Monterrey'), ('America/Montevideo', 'America/Montevideo'), ('America/Montserrat', 'America/Montserrat'), ('America/Nassau', 'America/Nassau'), ('America/New_York', 'America/New_York'), ('America/Nipigon', 'America/Nipigon'), ('America/Nome', 'America/Nome'), ('America/Noronha', 'America/Noronha'), ('America/North_Dakota/Beulah', 'America/North_Dakota/Beulah'), ('America/North_Dakota/Center', 'America/North_Dakota/Center'), ('America/North_Dakota/New_Salem', 'America/North_Dakota/New_Salem'), ('America/Nuuk', 'America/Nuuk'), ('America/Ojinaga', 'America/Ojinaga'), ('America/Panama', 'America/Panama'), ('America/Pangnirtung', 'America/Pangnirtung'), ('America/Paramaribo', 'America/Paramaribo'), ('America/Phoenix', 'America/Phoenix'), ('America/Port-au-Prince', 'America/Port-au-Prince'), ('America/Port_of_Spain', 'America/Port_of_Spain'), ('America/Porto_Velho', 'America/Porto_Velho'), ('America/Puerto_Rico', 'America/Puerto_Rico'), ('America/Punta_Arenas', 'America/Punta_Arenas'), ('America/Rainy_River', 'America/Rainy_River'), ('America/Rankin_Inlet', 'America/Rankin_Inlet'), ('America/Recife', 'America/Recife'), ('America/Regina', 'America/Regina'), ('America/Resolute', 'America/Resolute'), ('America/Rio_Branco', 'America/Rio_Branco'), ('America/Santarem', 'America/Santarem'), ('America/Santiago', 'America/Santiago'), ('America/Santo_Domingo', 'America/Santo_Domingo'), ('America/Sao_Paulo', 'America/Sao_Paulo'), ('America/Scoresbysund', 'America/Scoresbysund'), ('America/Sitka', 'America/Sitka'), ('America/St_Barthelemy', 'America/St_Barthelemy'), ('America/St_Johns', 'America/St_Johns'), ('America/St_Kitts', 'America/St_Kitts'), ('America/St_Lucia', 'America/St_Lucia'), ('America/St_Thomas', 'America/St_Thomas'), ('America/St_Vincent', 'America/St_Vincent'), ('America/Swift_Current', 'America/Swift_Current'), ('America/Tegucigalpa', 'America/Tegucigalpa'), ('America/Thule', 'America/Thule'), ('America/Thunder_Bay', 'America/Thunder_Bay'), ('America/Tijuana', 'America/Tijuana'), ('America/Toronto', 'America/Toronto'), ('America/Tortola', 'America/Tortola'), ('America/Vancouver', 'America/Vancouver'), ('America/Whitehorse', 'America/Whitehorse'), ('America/Winnipeg', 'America/Winnipeg'), ('America/Yakutat', 'America/Yakutat'), ('America/Yellowknife', 'America/Yellowknife'), ('Antarctica/Casey', 'Antarctica/Casey'), ('Antarctica/Davis', 'Antarctica/Davis'), ('Antarctica/DumontDUrville', 'Antarctica/DumontDUrville'), ('Antarctica/Macquarie', 'Antarctica/Macquarie'), ('Antarctica/Mawson', 'Antarctica/Mawson'), ('Antarctica/McMurdo', 'Antarctica/McMurdo'), ('Antarctica/Palmer', 'Antarctica/Palmer'), ('Antarctica/Rothera', 'Antarctica/Rothera'), ('Antarctica/Syowa', 'Antarctica/Syowa'), ('Antarctica/Troll', 'Antarctica/Troll'), ('Antarctica/Vostok', 'Antarctica/Vostok'), ('Arctic/Longyearbyen', 'Arctic/Longyearbyen'), ('Asia/Aden', 'Asia/Aden'), ('Asia/Almaty', 'Asia/Almaty'), ('Asia/Amman', 'Asia/Amman'), ('Asia/Anadyr', 'Asia/Anadyr'), ('Asia/Aqtau', 'Asia/Aqtau'), ('Asia/Aqtobe', 'Asia/Aqtobe'), ('Asia/Ashgabat', 'Asia/Ashgabat'), ('Asia/Atyrau', 'Asia/Atyrau'), ('Asia/Baghdad', 'Asia/Baghdad'), ('Asia/Bahrain', 'Asia/Bahrain'), ('Asia/Baku', 'Asia/Baku'), ('Asia/Bangkok', 'Asia/Bangkok'), ('Asia/Barnaul', 'Asia/Barnaul'), ('Asia/Beirut', 'Asia/Beirut'), ('Asia/Bishkek', 'Asia/Bishkek'), ('Asia/Brunei', 'Asia/Brunei'), ('Asia/Chita', 'Asia/Chita'), ('Asia/Choibalsan', 'Asia/Choibalsan'), ('Asia/Colombo', 'Asia/Colombo'), ('Asia/Damascus', 'Asia/Damascus'), ('Asia/Dhaka', 'Asia/Dhaka'), ('Asia/Dili', 'Asia/Dili'), ('Asia/Dubai', 'Asia/Dubai'), ('Asia/Dushanbe', 'Asia/Dushanbe'), ('Asia/Famagusta', 'Asia/Famagusta'), ('Asia/Gaza', 'Asia/Gaza'), ('Asia/Hebron', 'Asia/Hebron'), ('Asia/Ho_Chi_Minh', 'Asia/Ho_Chi_Minh'), ('Asia/Hong_Kong', 'Asia/Hong_Kong'), ('Asia/Hovd', 'Asia/Hovd'), ('Asia/Irkutsk', 'Asia/Irkutsk'), ('Asia/Jakarta', 'Asia/Jakarta'), ('Asia/Jayapura', 'Asia/Jayapura'), ('Asia/Jerusalem', 'Asia/Jerusalem'), ('Asia/Kabul', 'Asia/Kabul'), ('Asia/Kamchatka', 'Asia/Kamchatka'), ('Asia/Karachi', 'Asia/Karachi'), ('Asia/Kathmandu', 'Asia/Kathmandu'), ('Asia/Khandyga', 'Asia/Khandyga'), ('Asia/Kolkata', 'Asia/Kolkata'), ('Asia/Krasnoyarsk', 'Asia/Krasnoyarsk'), ('Asia/Kuala_Lumpur', 'Asia/Kuala_Lumpur'), ('Asia/Kuching', 'Asia/Kuching'), ('Asia/Kuwait', 'Asia/Kuwait'), ('Asia/Macau', 'Asia/Macau'), ('Asia/Magadan', 'Asia/Magadan'), ('Asia/Makassar', 'Asia/Makassar'), ('Asia/Manila', 'Asia/Manila'), ('Asia/Muscat', 'Asia/Muscat'), ('Asia/Nicosia', 'Asia/Nicosia'), ('Asia/Novokuznetsk', 'Asia/Novokuznetsk'), ('Asia/Novosibirsk', 'Asia/Novosibirsk'), ('Asia/Omsk', 'Asia/Omsk'), ('Asia/Oral', 'Asia/Oral'), ('Asia/Phnom_Penh', 'Asia/Phnom_Penh'), ('Asia/Pontianak', 'Asia/Pontianak'), ('Asia/Pyongyang', 'Asia/Pyongyang'), ('Asia/Qatar', 'Asia/Qatar'), ('Asia/Qostanay', 'Asia/Qostanay'), ('Asia/Qyzylorda', 'Asia/Qyzylorda'), ('Asia/Riyadh', 'Asia/Riyadh'), ('Asia/Sakhalin', 'Asia/Sakhalin'), ('Asia/Samarkand', 'Asia/Samarkand'), ('Asia/Seoul', 'Asia/Seoul'), ('Asia/Shanghai', 'Asia/Shanghai'), ('Asia/Singapore', 'Asia/Singapore'), ('Asia/Srednekolymsk', 'Asia/Srednekolymsk'), ('Asia/Taipei', 'Asia/Taipei'), ('Asia/Tashkent', 'Asia/Tashkent'), ('Asia/Tbilisi', 'Asia/Tbilisi'), ('Asia/Tehran', 'Asia/Tehran'), ('Asia/Thimphu', 'Asia/Thimphu'), ('Asia/Tokyo', 'Asia/Tokyo'), ('Asia/Tomsk', 'Asia/Tomsk'), ('Asia/Ulaanbaatar', 'Asia/Ulaanbaatar'), ('Asia/Urumqi', 'Asia/Urumqi'), ('Asia/Ust-Nera', 'Asia/Ust-Nera'), ('Asia/Vientiane', 'Asia/Vientiane'), ('Asia/Vladivostok', 'Asia/Vladivostok'), ('Asia/Yakutsk', 'Asia/Yakutsk'), ('Asia/Yangon', 'Asia/Yangon'), ('Asia/Yekaterinburg', 'Asia/Yekaterinburg'), ('Asia/Yerevan', 'Asia/Yerevan'), ('Atlantic/Azores', 'Atlantic/Azores'), ('Atlantic/Bermuda', 'Atlantic/Bermuda'), ('Atlantic/Canary', 'Atlantic/Canary'), ('Atlantic/Cape_Verde', 'Atlantic/Cape_Verde'), ('Atlantic/Faroe', 'Atlantic/Faroe'), ('Atlantic/Madeira', 'Atlantic/Madeira'), ('Atlantic/Reykjavik', 'Atlantic/Reykjavik'), ('Atlantic/South_Georgia', 'Atlantic/South_Georgia'), ('Atlantic/St_Helena', 'Atlantic/St_Helena'), ('Atlantic/Stanley', 'Atlantic/Stanley'), ('Australia/Adelaide', 'Australia/Adelaide'), ('Australia/Brisbane', 'Australia/Brisbane'), ('Australia/Broken_Hill', 'Australia/Broken_Hill'), ('Australia/Currie', 'Australia/Currie'), ('Australia/Darwin', 'Australia/Darwin'), ('Australia/Eucla', 'Australia/Eucla'), ('Australia/Hobart', 'Australia/Hobart'), ('Australia/Lindeman', 'Australia/Lindeman'), ('Australia/Lord_Howe', 'Australia/Lord_Howe'), ('Australia/Melbourne', 'Australia/Melbourne'), ('Australia/Perth', 'Australia/Perth'), ('Australia/Sydney', 'Australia/Sydney'), ('Canada/Atlantic', 'Canada/Atlantic'), ('Canada/Central', 'Canada/Central'), ('Canada/Eastern', 'Canada/Eastern'), ('Canada/Mountain', 'Canada/Mountain'), ('Canada/Newfoundland', 'Canada/Newfoundland'), ('Canada/Pacific', 'Canada/Pacific'), ('Europe/Amsterdam', 'Europe/Amsterdam'), ('Europe/Andorra', 'Europe/Andorra'), ('Europe/Astrakhan', 'Europe/Astrakhan'), ('Europe/Athens', 'Europe/Athens'), ('Europe/Belgrade', 'Europe/Belgrade'), ('Europe/Berlin', 'Europe/Berlin'), ('Europe/Bratislava', 'Europe/Bratislava'), ('Europe/Brussels', 'Europe/Brussels'), ('Europe/Bucharest', 'Europe/Bucharest'), ('Europe/Budapest', 'Europe/Budapest'), ('Europe/Busingen', 'Europe/Busingen'), ('Europe/Chisinau', 'Europe/Chisinau'), ('Europe/Copenhagen', 'Europe/Copenhagen'), ('Europe/Dublin', 'Europe/Dublin'), ('Europe/Gibraltar', 'Europe/Gibraltar'), ('Europe/Guernsey', 'Europe/Guernsey'), ('Europe/Helsinki', 'Europe/Helsinki'), ('Europe/Isle_of_Man', 'Europe/Isle_of_Man'), ('Europe/Istanbul', 'Europe/Istanbul'), ('Europe/Jersey', 'Europe/Jersey'), ('Europe/Kaliningrad', 'Europe/Kaliningrad'), ('Europe/Kiev', 'Europe/Kiev'), ('Europe/Kirov', 'Europe/Kirov'), ('Europe/Lisbon', 'Europe/Lisbon'), ('Europe/Ljubljana', 'Europe/Ljubljana'), ('Europe/London', 'Europe/London'), ('Europe/Luxembourg', 'Europe/Luxembourg'), ('Europe/Madrid', 'Europe/Madrid'), ('Europe/Malta', 'Europe/Malta'), ('Europe/Mariehamn', 'Europe/Mariehamn'), ('Europe/Minsk', 'Europe/Minsk'), ('Europe/Monaco', 'Europe/Monaco'), ('Europe/Moscow', 'Europe/Moscow'), ('Europe/Oslo', 'Europe/Oslo'), ('Europe/Paris', 'Europe/Paris'), ('Europe/Podgorica', 'Europe/Podgorica'), ('Europe/Prague', 'Europe/Prague'), ('Europe/Riga', 'Europe/Riga'), ('Europe/Rome', 'Europe/Rome'), ('Europe/Samara', 'Europe/Samara'), ('Europe/San_Marino', 'Europe/San_Marino'), ('Europe/Sarajevo', 'Europe/Sarajevo'), ('Europe/Saratov', 'Europe/Saratov'), ('Europe/Simferopol', 'Europe/Simferopol'), ('Europe/Skopje', 'Europe/Skopje'), ('Europe/Sofia', 'Europe/Sofia'), ('Europe/Stockholm', 'Europe/Stockholm'), ('Europe/Tallinn', 'Europe/Tallinn'), ('Europe/Tirane', 'Europe/Tirane'), ('Europe/Ulyanovsk', 'Europe/Ulyanovsk'), ('Europe/Uzhgorod', 'Europe/Uzhgorod'), ('Europe/Vaduz', 'Europe/Vaduz'), ('Europe/Vatican', 'Europe/Vatican'), ('Europe/Vienna', 'Europe/Vienna'), ('Europe/Vilnius', 'Europe/Vilnius'), ('Europe/Volgograd', 'Europe/Volgograd'), ('Europe/Warsaw', 'Europe/Warsaw'), ('Europe/Zagreb', 'Europe/Zagreb'), ('Europe/Zaporozhye', 'Europe/Zaporozhye'), ('Europe/Zurich', 'Europe/Zurich'), ('GMT', 'GMT'), ('Indian/Antananarivo', 'Indian/Antananarivo'), ('Indian/Chagos', 'Indian/Chagos'), ('Indian/Christmas', 'Indian/Christmas'), ('Indian/Cocos', 'Indian/Cocos'), ('Indian/Comoro', 'Indian/Comoro'), ('Indian/Kerguelen', 'Indian/Kerguelen'), ('Indian/Mahe', 'Indian/Mahe'), ('Indian/Maldives', 'Indian/Maldives'), ('Indian/Mauritius', 'Indian/Mauritius'), ('Indian/Mayotte', 'Indian/Mayotte'), ('Indian/Reunion', 'Indian/Reunion'), ('Pacific/Apia', 'Pacific/Apia'), ('Pacific/Auckland', 'Pacific/Auckland'), ('Pacific/Bougainville', 'Pacific/Bougainville'), ('Pacific/Chatham', 'Pacific/Chatham'), ('Pacific/Chuuk', 'Pacific/Chuuk'), ('Pacific/Easter', 'Pacific/Easter'), ('Pacific/Efate', 'Pacific/Efate'), ('Pacific/Enderbury', 'Pacific/Enderbury'), ('Pacific/Fakaofo', 'Pacific/Fakaofo'), ('Pacific/Fiji', 'Pacific/Fiji'), ('Pacific/Funafuti', 'Pacific/Funafuti'), ('Pacific/Galapagos', 'Pacific/Galapagos'), ('Pacific/Gambier', 'Pacific/Gambier'), ('Pacific/Guadalcanal', 'Pacific/Guadalcanal'), ('Pacific/Guam', 'Pacific/Guam'), ('Pacific/Honolulu', 'Pacific/Honolulu'), ('Pacific/Kiritimati', 'Pacific/Kiritimati'), ('Pacific/Kosrae', 'Pacific/Kosrae'), ('Pacific/Kwajalein', 'Pacific/Kwajalein'), ('Pacific/Majuro', 'Pacific/Majuro'), ('Pacific/Marquesas', 'Pacific/Marquesas'), ('Pacific/Midway', 'Pacific/Midway'), ('Pacific/Nauru', 'Pacific/Nauru'), ('Pacific/Niue', 'Pacific/Niue'), ('Pacific/Norfolk', 'Pacific/Norfolk'), ('Pacific/Noumea', 'Pacific/Noumea'), ('Pacific/Pago_Pago', 'Pacific/Pago_Pago'), ('Pacific/Palau', 'Pacific/Palau'), ('Pacific/Pitcairn', 'Pacific/Pitcairn'), ('Pacific/Pohnpei', 'Pacific/Pohnpei'), ('Pacific/Port_Moresby', 'Pacific/Port_Moresby'), ('Pacific/Rarotonga', 'Pacific/Rarotonga'), ('Pacific/Saipan', 'Pacific/Saipan'), ('Pacific/Tahiti', 'Pacific/Tahiti'), ('Pacific/Tarawa', 'Pacific/Tarawa'), ('Pacific/Tongatapu', 'Pacific/Tongatapu'), ('Pacific/Wake', 'Pacific/Wake'), ('Pacific/Wallis', 'Pacific/Wallis'), ('US/Alaska', 'US/Alaska'), ('US/Arizona', 'US/Arizona'), ('US/Central', 'US/Central'), ('US/Eastern', 'US/Eastern'), ('US/Hawaii', 'US/Hawaii'), ('US/Mountain', 'US/Mountain'), ('US/Pacific', 'US/Pacific'), ('UTC', 'UTC')], default='UTC', max_length=255, verbose_name='Timezone')),
                ('mails_sent', models.BooleanField(default=False, verbose_name='If e-mail has been sent')),
                ('host', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='hosted_events', to=settings.AUTH_USER_MODEL, verbose_name='Host')),
            ],
            options={
                'verbose_name': 'Event',
                'verbose_name_plural': 'Events',
                'ordering': ('start',),
            },
        ),
        migrations.CreateModel(
            name='MailTemplate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('type', models.CharField(choices=[('join_confirmation', 'Join Confirmation'), ('host_confirmation', 'Host Confirmation'), ('join', 'Join'), ('deleted', 'Event deleted Notification')], max_length=255, verbose_name='Type')),
                ('subject_template', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, verbose_name='Subject Template')),
                ('subject_template_af', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_ar', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_ast', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_az', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_bg', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_be', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_bn', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_br', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_bs', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_ca', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_cs', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_cy', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_da', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_de', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_dsb', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_el', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_en', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_en_au', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_en_gb', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_eo', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_es', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_es_ar', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_es_co', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_es_mx', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_es_ni', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_es_ve', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_et', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_eu', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_fa', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_fi', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_fr', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_fy', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_ga', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_gd', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_gl', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_he', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_hi', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_hr', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_hsb', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_hu', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_hy', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_ia', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_ind', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_io', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_is', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_it', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_ja', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_ka', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_kab', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_kk', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_km', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_kn', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_ko', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_lb', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_lt', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_lv', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_mk', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_ml', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_mn', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_mr', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_my', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_nb', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_ne', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_nl', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_nn', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_os', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_pa', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_pl', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_pt', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_pt_br', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_ro', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_ru', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_sk', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_sl', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_sq', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_sr', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_sr_latn', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_sv', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_sw', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_ta', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_te', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_th', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_tr', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_tt', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_udm', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_uk', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_ur', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_uz', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_vi', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_zh_hans', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('subject_template_zh_hant', models.CharField(help_text='Subject of the email to be sent. The Variable {{ event }} and its children {{ event.start }} etc. can be used.', max_length=255, null=True, verbose_name='Subject Template')),
                ('body_template', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', verbose_name='Body Template')),
                ('body_template_af', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_ar', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_ast', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_az', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_bg', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_be', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_bn', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_br', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_bs', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_ca', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_cs', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_cy', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_da', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_de', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_dsb', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_el', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_en', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_en_au', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_en_gb', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_eo', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_es', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_es_ar', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_es_co', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_es_mx', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_es_ni', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_es_ve', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_et', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_eu', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_fa', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_fi', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_fr', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_fy', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_ga', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_gd', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_gl', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_he', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_hi', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_hr', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_hsb', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_hu', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_hy', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_ia', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_ind', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_io', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_is', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_it', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_ja', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_ka', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_kab', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_kk', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_km', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_kn', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_ko', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_lb', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_lt', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_lv', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_mk', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_ml', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_mn', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_mr', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_my', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_nb', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_ne', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_nl', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_nn', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_os', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_pa', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_pl', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_pt', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_pt_br', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_ro', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_ru', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_sk', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_sl', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_sq', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_sr', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_sr_latn', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_sv', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_sw', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_ta', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_te', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_th', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_tr', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_tt', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_udm', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_uk', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_ur', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_uz', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_vi', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_zh_hans', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
                ('body_template_zh_hant', models.TextField(help_text='Body text of the email to be sent. The Variable {{ event }} and its children {{ event.start }}, {{ event.join_url }}, {{ event.delete_url }} etc. can be used. Also: {{ leave_url }} for join template only. Note that all datetimes are evaluated in the timezone of the event.', null=True, verbose_name='Body Template')),
            ],
            options={
                'verbose_name': 'MailTemplate',
                'verbose_name_plural': 'MailTemplates',
                'ordering': ('type',),
            },
        ),
        migrations.CreateModel(
            name='Participation',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('uuid', models.UUIDField(default=uuid.uuid4)),
                ('event', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='arrange_videochat.Event')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'Participation',
                'verbose_name_plural': 'Participations',
            },
        ),
        migrations.AddField(
            model_name='event',
            name='participants',
            field=models.ManyToManyField(related_name='events', through='arrange_videochat.Participation', to=settings.AUTH_USER_MODEL, verbose_name='Participants'),
        ),
    ]
