{% extends "base.html" %}
{% load i18n %}

{% block body %}form{% endblock body %}

{% block content %}
<div class="container">
  <div class="row">
    <div class="col-sm-12">

      <h2>{% trans "You are participating" %}</h2>
      <p>
        {% blocktrans with date=event.start timezone=event.start|date:"e" %}In the event happening at <b>{{ date }}</b> ({{ timezone }}){% endblocktrans %}
      </p>
      <a href="mailto:?subject=Invitation to join my event!&body=Hey, I am participating in a event on {{ request.scheme }}://{{ request.get_host }}. It is basically an online meeting, where we share our thoughts and feelings and I would like to invite you to join us here: {{ request.scheme }}://{{ request.get_host }}{% url 'arrange_videochat:participate' event.id %}" class="btn btn-secondary">{% trans "Invite people to join this event by email" %}</a>
      <a href="https://www.facebook.com/sharer/sharer.php?u={{ request.scheme }}://{{ request.get_host }}{% url 'arrange_videochat:participate' event.id %}&amp;src=sdkpreparse" class="btn btn-primary" class="btn btn-primary">{% trans "Invite people to join the event on Facebook" %}</a>

    </div>
  </div>
</div>
{% endblock content %}