{% extends "base.html" %}
{% load i18n %}
{% load crispy_forms_tags %}

{% block body %}form{% endblock body %}

{% block content %}

{% include "./_terms_modal.html" %}

<div class="container">
  <div class="row">
		<div class="col-sm-12 col-md-6">

      <h2>{% trans "Host an Event" %}</h2>

      <form target="{% url 'arrange_videochat:host' %}" method="POST">
        {% csrf_token %}
        {{ form|crispy }}
        <a class="btn btn-outline-secondary" href="{% url 'arrange_videochat:list' %}">{% trans "Cancel" %}</a>
        <button type="submit" class="btn btn-primary">{% trans "Host" %}</button>
      </form>
      
    </div>
  </div>
</div>

{% endblock content %}

{% block extrafooter %}

{{ form.media }}

<script type="text/javascript">
    $(window).on('load',function(){
        $('.terms').modal('show');
    });
</script>
  
{% endblock extrafooter %}