from django.apps import AppConfig
from django.utils.translation import ugettext_lazy as _


class ArrangeVideoCharConfig(AppConfig):
    name = "arrange_videochat"
    verbose_name = _("Arrange Videochat")
